/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2024. All rights reserved.
 */

#ifndef DPC_IMPL_TYPE_CARPOSITION_H
#define DPC_IMPL_TYPE_CARPOSITION_H

#include "impl_type_uint8.h"
#include "dpc/impl_type_vector_uint8.h"

namespace dpc {
struct CarPosition {
    ::UInt8 ego_lane_id{ 0U };
    ::UInt8 lane_line_crossed{ 0U };
    ::dpc::vector_uint8 target_lane_id_list;

    static bool IsPlane()
    {
        return false;
    }


    using IsEnumerableTag = void;
    template<typename F>
    void enumerate(F& fun)
    {
        fun(ego_lane_id);
        fun(lane_line_crossed);
        fun(target_lane_id_list);
    }

    template<typename F>
    void enumerate(F& fun) const
    {
        fun(ego_lane_id);
        fun(lane_line_crossed);
        fun(target_lane_id_list);
    }

    template<typename F>
    void enumerate_internal(F& fun)
    {
        fun("ego_lane_id", ego_lane_id);
        fun("lane_line_crossed", lane_line_crossed);
        fun("target_lane_id_list", target_lane_id_list);
    }

    template<typename F>
    void enumerate_internal(F& fun) const
    {
        fun("ego_lane_id", ego_lane_id);
        fun("lane_line_crossed", lane_line_crossed);
        fun("target_lane_id_list", target_lane_id_list);
    }

    friend bool operator==(const ::dpc::CarPosition& lhs, const ::dpc::CarPosition& rhs) noexcept
    {
        return (lhs.ego_lane_id == rhs.ego_lane_id) && (lhs.lane_line_crossed == rhs.lane_line_crossed) && (lhs.target_lane_id_list == rhs.target_lane_id_list);
    }
};
} // namespace dpc


#endif // DPC_IMPL_TYPE_CARPOSITION_H
